Chapter 3: Pipelines
====================

In chapter 3, we introduce lens modeling **Pipeline**'s that fit a strong lens using a sequence of non-linear searches
which each fit a different lens model.

You can start the tutorials right now by going to `our binder <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/HEAD>`_
and navigating to the folder ``notebooks/howtolens/chapter_3_pipelines``. They are also on the `autolens_workspace <https://github.com/Jammy2211/autolens_workspace>`_.


The chapter contains the following tutorials:

`Tutorial 1: Pipeline Lens and Source <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_3_pipelines/tutorial_1_pipeline_runner.ipynb>`_
- Fitting the lens's light followed by its mass.

`Tutorial 2: Pipeline Two Lens Galaxies <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_3_pipelines/tutorial_2_pipeline_runner.ipynb>`_
- Modeling a strong lens with two lens galaxies.

`Tutorial 3: Pipeline Complex Source <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_3_pipelines/tutorial_3_pipeline_runner.ipynb>`_
- Using multiple light profiles to fit a complex and irregular source.

`Tutorial 4: Setup and SLaM <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_3_pipelines/tutorial_4_setup_and_slam.ipynb>`_
- Template objects and pipelines for fitting lens model is standardized ways.